==> smartgwtee-eval-5.1p.zip: com/smartgwt/logicalstructure/widgets/form/ColorPickerLogicalStructure.java <==
package com.smartgwt.logicalstructure.widgets.form;
import com.smartgwt.client.core.*;
import com.smartgwt.client.rpc.*;
import com.smartgwt.client.i18n.*;
import com.smartgwt.client.event.*;
import com.smartgwt.client.util.*;
import com.smartgwt.client.util.workflow.*;
import com.smartgwt.client.types.*;
import com.smartgwt.client.data.*;
import com.smartgwt.client.data.fields.*;
import com.smartgwt.client.tools.*;
import com.smartgwt.client.widgets.*;
import com.smartgwt.client.widgets.calendar.*;
import com.smartgwt.client.widgets.chart.*;
import com.smartgwt.client.widgets.cube.*;
import com.smartgwt.client.widgets.drawing.*;
import com.smartgwt.client.widgets.form.*;
import com.smartgwt.client.widgets.form.fields.*;
import com.smartgwt.client.widgets.form.validator.*;
import com.smartgwt.client.widgets.grid.*;
import com.smartgwt.client.widgets.layout.*;
import com.smartgwt.client.widgets.menu.*;
import com.smartgwt.client.widgets.plugins.*;
import com.smartgwt.client.widgets.tab.*;
import com.smartgwt.client.widgets.tableview.*;
import com.smartgwt.client.widgets.tile.*;
import com.smartgwt.client.widgets.toolbar.*;
import com.smartgwt.client.widgets.tree.*;
import com.smartgwt.client.widgets.viewer.*;
import com.smartgwt.logicalstructure.core.*;
import com.smartgwt.logicalstructure.widgets.*;
import com.smartgwt.logicalstructure.widgets.form.*;
import com.smartgwt.logicalstructure.widgets.tile.*;
import com.smartgwt.logicalstructure.widgets.grid.*;
import com.smartgwt.logicalstructure.widgets.chart.*;
import com.smartgwt.logicalstructure.widgets.layout.*;
import com.smartgwt.logicalstructure.widgets.menu.*;
import com.smartgwt.logicalstructure.widgets.tab.*;
import com.smartgwt.logicalstructure.widgets.toolbar.*;
import com.smartgwt.logicalstructure.widgets.tree.*;
import com.smartgwt.logicalstructure.widgets.viewer.*;
import com.smartgwt.logicalstructure.widgets.calendar.*;
import com.smartgwt.logicalstructure.widgets.cube.*;
import com.smartgwt.logicalstructure.widgets.drawing.*;

public class ColorPickerLogicalStructure extends WindowLogicalStructure {
    public String allowComplexMode;
    public String autoCenterOnShow;
    public String autoPosition;
    public String basicColorLabel;
    public String blueFieldPrompt;
    public String blueFieldTitle;
    public String cancelButtonTitle;
    public String[] colorArray;
    public String colorButtonBaseStyle;
    public String colorButtonSize;
    public String crosshairImageURL;
    public String defaultColor;
    public String defaultOpacity;
    public String defaultPickMode;
    public String greenFieldPrompt;
    public String greenFieldTitle;
    public String htmlFieldPrompt;
    public String htmlFieldTitle;
    public String hueFieldPrompt;
    public String hueFieldTitle;
    public String lessButtonTitle;
    public String lumFieldPrompt;
    public String lumFieldTitle;
    public String lumWidth;
    public String moreButtonTitle;
    public String okButtonTitle;
    public String opacitySliderLabel;
    public String opacityText;
    public String redFieldPrompt;
    public String redFieldTitle;
    public String satFieldPrompt;
    public String satFieldTitle;
    public String selectedColorLabel;
    public String supportsTransparency;
    public String swatchHeight;
    public String swatchImageURL;
    public String swatchWidth;
}

==> smartgwtee-eval-12.1p.zip: com/smartgwt/logicalstructure/widgets/form/ColorPickerLogicalStructure.java <==
package com.smartgwt.logicalstructure.widgets.form;
import com.smartgwt.client.core.*;
import com.smartgwt.client.rpc.*;
import com.smartgwt.client.i18n.*;
import com.smartgwt.client.event.*;
import com.smartgwt.client.util.*;
import com.smartgwt.client.util.workflow.*;
import com.smartgwt.client.util.workflow.Process; // required to override java.lang.Process
import com.smartgwt.client.types.*;
import com.smartgwt.client.data.*;
import com.smartgwt.client.data.Record;
import com.smartgwt.client.data.fields.*;
import com.smartgwt.client.tools.*;
import com.smartgwt.client.widgets.*;
import com.smartgwt.client.widgets.calendar.*;
import com.smartgwt.client.widgets.chart.*;
import com.smartgwt.client.widgets.cube.*;
import com.smartgwt.client.widgets.drawing.*;
import com.smartgwt.client.widgets.form.*;
import com.smartgwt.client.widgets.form.fields.*;
import com.smartgwt.client.widgets.form.validator.*;
import com.smartgwt.client.widgets.grid.*;
import com.smartgwt.client.widgets.layout.*;
import com.smartgwt.client.widgets.menu.*;
import com.smartgwt.client.widgets.plugins.*;
import com.smartgwt.client.widgets.tab.*;
import com.smartgwt.client.widgets.tableview.*;
import com.smartgwt.client.widgets.tile.*;
import com.smartgwt.client.widgets.toolbar.*;
import com.smartgwt.client.widgets.tree.*;
import com.smartgwt.client.widgets.viewer.*;
import com.smartgwt.logicalstructure.core.*;
import com.smartgwt.logicalstructure.widgets.*;
import com.smartgwt.logicalstructure.widgets.form.*;
import com.smartgwt.logicalstructure.widgets.tile.*;
import com.smartgwt.logicalstructure.widgets.grid.*;
import com.smartgwt.logicalstructure.widgets.chart.*;
import com.smartgwt.logicalstructure.widgets.layout.*;
import com.smartgwt.logicalstructure.widgets.menu.*;
import com.smartgwt.logicalstructure.widgets.tab.*;
import com.smartgwt.logicalstructure.widgets.toolbar.*;
import com.smartgwt.logicalstructure.widgets.tree.*;
import com.smartgwt.logicalstructure.widgets.viewer.*;
import com.smartgwt.logicalstructure.widgets.calendar.*;
import com.smartgwt.logicalstructure.widgets.cube.*;
import com.smartgwt.logicalstructure.widgets.drawing.*;

public class ColorPickerLogicalStructure extends WindowLogicalStructure {
    public String allowComplexMode;
    public String autoCenterOnShow;
    public String autoHide;
    public String autoPosition;
    public String basicColorLabel;
    public String blueFieldPrompt;
    public String blueFieldTitle;
    public String cancelButtonTitle;
    public String[] colorArray;
    public String colorButtonBaseStyle;
    public String colorButtonSize;
    public String crosshairImageURL;
    public String defaultColor;
    public String defaultOpacity;
    public String defaultPickMode;
    public String greenFieldPrompt;
    public String greenFieldTitle;
    public String htmlFieldPrompt;
    public String htmlFieldTitle;
    public String hueFieldPrompt;
    public String hueFieldTitle;
    public String lessButtonTitle;
    public String lumFieldPrompt;
    public String lumFieldTitle;
    public String lumWidth;
    public String moreButtonTitle;
    public String okButtonTitle;
    public String opacitySliderLabel;
    public String opacityText;
    public String redFieldPrompt;
    public String redFieldTitle;
    public String satFieldPrompt;
    public String satFieldTitle;
    public String selectedColorLabel;
    public String showCancelButton;
    public String showModeToggleButton;
    public String showOkButton;
    public String supportsTransparency;
    public String swatchHeight;
    public String swatchImageURL;
    public String swatchWidth;
}
